import time
import random

import cv2

if __name__ == '__main__':
    print('run program')
    rtsp_address = 'rtmp://58.200.131.2:1935/livetv/hunantv'
    # rtsp_address = 'rtsp://wowzaec2demo.streamlock.net/vod/mp4:BigBuckBunny_115k.mov'

    # 通过cv2中的类获取视频流操作对象cap
    cap = cv2.VideoCapture(rtsp_address)
    # 调用cv2方法获取cap的视频帧（帧：每秒多少张图片）
    fps = cap.get(cv2.CAP_PROP_FPS)
    print(fps)
    # 获取cap视频流的每帧大小
    size = (int(cap.get(cv2.CAP_PROP_FRAME_WIDTH)),
            int(cap.get(cv2.CAP_PROP_FRAME_HEIGHT)))
    print(size)
    # 定义编码格式mpge-4
    fourcc = cv2.VideoWriter_fourcc('M', 'P', '4', '2')
    # 定义视频文件输入对象
    outVideo = cv2.VideoWriter('/home/wwl/mypython/myworkspace/test/video/saveDir.avi', fourcc, fps, size)
    cv2.namedWindow("cap video", 0)

    while True:
        ret, image = cap.read()
        if ret is True:
            for temp in range(random.randint(1, 16)):
                x1 = random.randint(1, 960)
                y1 = random.randint(1, 540)

                x2 = x1 + random.randint(1, 960)
                y2 = y1 + random.randint(1, 540)

                cv2.rectangle(image, (x1, y1), (x2, y2), (random.randint(0, 256), random.randint(0, 256), random.randint(0, 256)), 3)
                cv2.putText(image, str(temp)+str(":via:") + str(random.random()), (x1, y1), cv2.FONT_HERSHEY_SIMPLEX, 1,
                            (0, 255, 0), 2)
            print(type(image))
            print(image)
            cv2.imshow('cap video', image)
            cv2.imwrite("/home/wwl/mypython/myworkspace/test/pic/" + str(time.time()) + ".jpg", image)
            outVideo.write(image)
        if cv2.waitKey(1) & 0xFF == ord('q'):
            outVideo.release()
            cap.release()
            cv2.destroyAllWindows()
            break
            # continue



import os
import subprocess
import time
import threading

#
# def convert_avi_to_mp4(avi_file_path, output_name):
#     print("1")
#     os.popen("ffmpeg -i '{input}' -ac 2 -b:v 2000k -c:a aac -c:v libx264 -b:a 160k -vprofile high -bf 0 -strict experimental -f mp4 '{output}'".format(input=avi_file_path, output=output_name))
#     time.sleep(1)
#     print("2")
#     return True
#
#
#
# convert_avi_to_mp4("/home/wwl/myui/myworkspace/testing/avi2mp4/aaa.avi",
#                    "/home/wwl/myui/myworkspace/testing/avi2mp4/yie.mp4")

import threading


class MyThread(threading.Thread):
    def __init__(self, avi_file_path, out_file_path):
        super(MyThread, self).__init__()
        self.avi_file_path = avi_file_path
        self.out_file_path = out_file_path

    def run(self):
        print("1")
        #os.popen("ffmpeg -i '{input}' -ac 2 -b:v 2000k -c:a aac -c:v libx264 -b:a 160k -vprofile high -bf 0 -strict experimental -f mp4 '{output}'".format(input=self.avi_file_path, output=self.out_file_path))
        #subprocess.run("ffmpeg -i '{input}' -ac 2 -b:v 2000k -c:a aac -c:v libx264 -b:a 160k -vprofile high -bf 0 -strict experimental -f mp4 '{output}'".format(input=self.avi_file_path, output=self.out_file_path))
        os.system("ffmpeg -i '{input}' -ac 2 -b:v 2000k -c:a aac -c:v libx264 -b:a 160k -vprofile high -bf 0 -strict experimental -f mp4 '{output}'".format(input=self.avi_file_path, output=self.out_file_path))
        # time.sleep(1)
        print("2")


if __name__ == '__main__':
    print("VidoFormatTransformThread Start")
    #vidoFormatTransformThread = MyThread("/home/wwl/myui/myworkspace/testing/avi2mp4/via.avi", "/home/wwl/myui/myworkspace/testing/avi2mp4/yie.mp4")
    vidoFormatTransformThread = MyThread("/home/wwl/myui/myworkspace/testing/avi2mp4/aaa.avi",
                                         "/home/wwl/myui/myworkspace/testing/avi2mp4/yie.mp4")
    vidoFormatTransformThread.start()
    #vidoFormatTransformThread.join()
    print("VidoFormatTransformThread Finish")
    #sudo docker commit -a "jianglinzhang" -m "8997d910edcb" wellsecurity_portal_nginx wellsecurity_portal_nginx:latest
    #sudo docker commit -a "jianglinzhang" -m "via wellsecurity-osk-server-conda" wellsecurity-osk-server-conda wellsecurity-osk-server-conda:latest
    #sudo docker save -o wellsecurity-osk-server-conda.tar wellsecurity-osk-server-conda:latest
    #sudo docker save -o wellsecurity_portal_nginx.tar wellsecurity_portal_nginx:latest



# -*- coding: utf-8 -*-
# @Time : 2021/7/9 上午11:17
# @Author : Jianglin Zhang
# @File : testing.py

import xml.etree.ElementTree as ET
import os


class Voc2Yolo:

    def __init__(self, defaultImgWidth=1920, defaultImgHeight=1080):
        self.defaultImgWidth = defaultImgWidth
        self.defaultImgHeight = defaultImgHeight

    @staticmethod
    def transfer_coordinate(size, box):

        x_center = (box[0] + box[1]) / 2.0
        y_center = (box[2] + box[3]) / 2.0
        x = x_center / size[0]
        y = y_center / size[1]
        w = (box[1] - box[0]) / size[0]
        h = (box[3] - box[2]) / size[1]
        return x, y, w, h

    def convert_annotation(self, xml_files_path, save_txt_files_path, need_deal_class_list):
        xml_files = os.listdir(xml_files_path)
        for xml_name in xml_files:
            # print(xml_name)
            if str(xml_name).find(".xml") < 0:
                continue
            xml_file = os.path.join(xml_files_path, xml_name)
            out_txt_path = os.path.join(save_txt_files_path, xml_name.split('.')[0] + '.txt')
            out_txt_f = open(out_txt_path, 'w')
            tree = ET.parse(xml_file)
            root = tree.getroot()
            size = root.find('size')
            w = int(size.find('width').text)
            h = int(size.find('height').text)
            if w is None or w == 0:
                w = self.defaultImgWidth
            if h is None or h == 0:
                h = self.defaultImgHeight

            for obj in root.iter('object'):
                difficult = obj.find('difficult').text
                cls = obj.find('name').text
                if cls not in need_deal_class_list or int(difficult) == 1:
                    continue
                cls_id = need_deal_class_list.index(cls)
                xmlbox = obj.find('bndbox')
                b = (float(xmlbox.find('xmin').text), float(xmlbox.find('xmax').text), float(xmlbox.find('ymin').text),
                     float(xmlbox.find('ymax').text))
                # b=(xmin, xmax, ymin, ymax)
                # print(w, h, b)
                bb = self.transfer_coordinate((w, h), b)
                out_txt_f.write(str(cls_id) + " " + " ".join([str(a) for a in bb]) + '\n')


if __name__ == "__main__":
    # 把forklift_pallet的voc的xml标签文件转化为yolo的txt标签文件
    # 1、需要转化的类别
    need_deal_class_list = ['allcar', 'truck', 'car', 'authorize', 'human', 'tail', 'authorize_squat', 'authorize_sit',
                            'chacar',
                            'highcar', 'vest_squat', 'authorize_recline', 'vest', 'helmet', 'human_squat', 'helmet_sit']
    # 2、voc格式的xml标签文件路径
    xml_files_path = r'/home/wwl/mypython/myworkspace/vialearning/mwdstesting'
    # 3、转化为yolo格式的txt标签文件存储路径
    save_txt_files_path = r'/home/wwl/mypython/myworkspace/vialearning/mwdstesting'

    voc2Yolo = Voc2Yolo()
    voc2Yolo.convert_annotation(xml_files_path, save_txt_files_path, need_deal_class_list)



# import time
#
# tempTime = time.time()
# print(tempTime)
# tempTimeLocal = time.localtime(tempTime)
# print(tempTimeLocal)
# rq = time.strftime('%Y%m%d%H%M', tempTimeLocal)
# print(rq)
#
# rq = time.strftime('%Y%m%d%H%M%S', tempTimeLocal)
# print(rq)
#
# rq = time.strftime('%Y%m%d%H%M%s', tempTimeLocal)
# print(rq)
#
# rq = time.strftime('%s', tempTimeLocal)
# print(rq)

"""
from copy import deepcopy


class User:
    def __init__(self, name, age):
        self.name = name
        self.age = age

    def setName(self, name):
        self.name = name

    def setAge(self, age):
        self.age = age

    def detail(self):
        print(str(self.name) + str(self.age))


user = User("via", "27")
user.detail()
print(user)
userBackup1 = user
userBackup1.detail()
print(userBackup1)
userDeepCopy = deepcopy(user)
userDeepCopy.detail()
print(userDeepCopy)
user.setName("yie")

userBackup2 = user
userBackup2.detail()
print(userBackup2)

print("_____________________")
user.detail()
userBackup1.detail()
userDeepCopy.detail()
userBackup2.detail()

"""

# from torch.cuda import amp
# scaler = amp.GradScaler(enabled=cuda)

# import torch
# import torch.distributed as dist   # ！！！！！！！！！！！！！！！！！！！！！！！！
# from torch.utils.data.distributed import DistributedSampler  # ！！！！！！！！！！！！！！！！！！！
#
# dist.init_process_group(backend='nccl', init_method='env://')  # ！！！！！！！！！！！！！！！！！！！！！
# batch_size = 12  # 主卡上的batchsize      # ！！！！！！！！！！！！！！！！！！！！！！！！！！
# data_size = 25  # 总共的batchsize   # ！！！！！！！！！！！！！！！！！！！
# local_rank = torch.distributed.get_rank()
# print(local_rank)

"""
Hi ,
#1、安装pptp-linux
sudo apt-get install pptp-linux binutils
#2、建立pptp连接
sudo pptpsetup --create testvpn --server 207.148.109.43 --username via --password yie --encrypt --start
#2.1ifconfig查看pptp建立后的通信ip和网关， eg: inet 192.168.0.111  netmask 255.255.255.255  destination 192.168.0.1
#3、添加默认路由(备注:对应的网关地址和默认路由按自己的配置)
sudo route add default gw 192.168.0.1
#4、删除默认路由
sudo route del default gw 10.66.79.254
#5、恢复原有路由
sudo route add default gw 10.66.79.254


sudo pptpsetup --create testvpn --server 207.148.109.43 --username via --password yie --encrypt --start
sudo route add default gw 192.168.0.1
sudo route del default gw 10.66.79.254



sudo route add default gw 10.66.79.254
sudo route del default gw 192.168.0.1

smb://192.168.110.16/westwell-alpha/	westwell-alpha	Alpha-WWL	alpha组使用


"""

from tqdm import tqdm
import time
for char in tqdm(["a", "b", "c", "d"]):
    #do something
    time.sleep(2)
    pass


class WSTypeQualificationException(Exception):
    pass


class ObjectType:
    rectangle = "rectangle"
    polygon = "polygon"


class Point:
    def __init__(self, x: str = None, y: str = None, z: str = None, additional_data: str = None):
        self.x = x
        self.y = y
        self.z = z
        self.additional_data = additional_data


class PointList(list):
    def append(self, temp_object):
        if type(temp_object) is not Point:
            raise WSTypeQualificationException("The type must be Point.")
        super().append(temp_object)


class InferenceResult:
    def __init__(self, id: str, name: str, point_list: PointList, confidence: str, object_type: ObjectType):
        self.id = id
        self.name = name
        self.point_list = point_list
        self.confidence = confidence
        self.object_type = object_type


class InferenceResultList(list):
    def append(self, temp_object):
        if type(temp_object) is not InferenceResult:
            raise WSTypeQualificationException("The type must be InferenceResult.")
        super().append(temp_object)


class PictureAddressList(list):
    def append(self, temp_object):
        if type(temp_object) is not str:
            raise WSTypeQualificationException("The type must be str.")
        super().append(temp_object)


class MessageData:
    def __init__(self, stream_address: str, video_address: str, picture_address_list: PictureAddressList,
                 inference_result_list: InferenceResultList):
        self.stream_address = stream_address
        self.video_address = video_address
        self.picture_address_list = picture_address_list
        self.inference_result_list = inference_result_list


class MessageType:
    wellsucurity = "wellsucurity"
    unknown = "unknown"
    testing = "testing"


class MessageProducerState:
    def __init__(self, start=True, intermediate=False, end=False, id: str = None, signature: str = None):
        self.start = start
        self.intermediate = intermediate
        self.end = end
        self.id = id
        self.signature = signature


class MessageConsumerState:
    def __init__(self, start=True, intermediate=False, end=False, id: str = None, signature: str = None):
        self.start = start
        self.intermediate = intermediate
        self.end = end
        self.id = id
        self.signature = signature


class MessageConsumerStateList(list):
    def append(self, temp_object):
        if type(temp_object) is not MessageConsumerState:
            raise WSTypeQualificationException("The type must be MessageConsumerState.")
        super().append(temp_object)


class Message:
    def __init__(self, message_id: str = None, start_timestamp: str = None, end_timestamp: str = None,
                 message_producer_state: MessageProducerState = None,
                 message_consumer_state_list: MessageConsumerStateList = None,
                 message_type: str = None,
                 message_data: MessageData = None, additional_data: dict = None):
        self.message_id = message_id
        self.start_timestamp = start_timestamp
        self.end_timestamp = end_timestamp
        self.message_producer_state = message_producer_state
        self.message_consumer_state_list = message_consumer_state_list
        self.message_type = message_type
        self.message_data = message_data
        self.additional_data = additional_data

    # def __repr__(self):
    #     return repr((self.message_id, self.start_timestamp, self.end_timestamp))


class WSJsonUtils():
    def __init__(self):
        self.jresult = ""

    def loopKV(self, x):
        if hasattr(x, "__dict__"):
            for temp in x.__dict__:
                k1 = x.__getattribute__(temp)
                if isinstance(k1, int) or isinstance(k1, float) or isinstance(k1, str) or isinstance(k1, bool) or k1 is None:
                    #print(str(temp) + "______" + str(k1) + "______" + str(type(k1)))
                    self.jresult += '"' + str(temp) + '"' + ":" + '"' + str(k1) + '"' + ","
                    pass
                elif isinstance(k1, list):
                    self.jresult += '"' + str(temp) + '"' + ":" + '['
                    for k2 in k1:
                        self.jresult += '{'
                        self.loopKV(k2)
                        self.jresult += '}' + ","
                    self.jresult += ']' + ","
                elif isinstance(k1, set):
                    #print(k1)
                    pass
                elif isinstance(k1, dict):
                    #print(k1)
                    pass
                else:
                    self.jresult += '"' + str(temp) + '"' + ":" + '{'
                    self.loopKV(k1)
                    self.jresult += '}' + ","
        else:
            # print(x)
            pass

    def transfer2json(self, content):
        self.loopKV(content)
        result = "{" + self.jresult + "}"
        import re
        result = re.compile(",}").sub("}", result)
        result = re.compile(",]").sub("]", result)
        return result


if __name__ == '__main__':
    pointList = PointList(list())
    pointList.append(Point(100, 111))
    pointList.append(Point(200, 211))

    inferenceResult1 = InferenceResult(id="1000001", name="no_vest", point_list=pointList, confidence="0.99",
                                       object_type=ObjectType.rectangle)
    inferenceResult2 = InferenceResult(id="1000002", name="no_helmet", point_list=pointList, confidence="0.61",
                                       object_type=ObjectType.rectangle)
    inferenceResult3 = InferenceResult(id="1000003", name="pedestrian", point_list=pointList, confidence="0.47",
                                       object_type=ObjectType.rectangle)

    inferenceResultList = InferenceResultList(list())
    inferenceResultList.append(inferenceResult1)
    inferenceResultList.append(inferenceResult2)
    inferenceResultList.append(inferenceResult3)

    pictureAddressList = PictureAddressList(list())
    pictureAddressList.append("http://a.com/wellsecurity/yantian/static/2021/06/28/07/33/camera1001/aaa1.jpg")
    pictureAddressList.append("http://a.com/wellsecurity/yantian/static/2021/06/28/07/33/camera1001/aaa2.jpg")
    pictureAddressList.append("http://a.com/wellsecurity/yantian/static/2021/06/28/07/33/camera1001/aaa3.jpg")

    messageData = MessageData(stream_address="rtsp://192.168.110.66", video_address="http://10.66.8.24/vvvv.mp4",
                              picture_address_list=pictureAddressList, inference_result_list=inferenceResultList)

    messageProducerState = MessageProducerState(start=True, intermediate=True, end=False, id="1001",
                                                signature="wwwwww")

    messageConsumerState1 = MessageConsumerState(start=True, intermediate=True, end=False, id="2001",
                                                 signature="dfsdfdsf")
    messageConsumerState2 = MessageConsumerState(start=True, intermediate=True, end=False, id="2002",
                                                 signature="mmmmmmmk")
    messageConsumerState3 = MessageConsumerState(start=True, intermediate=True, end=False, id="2003",
                                                 signature="vvvvvvvv")
    messageConsumerStateList = MessageConsumerStateList()
    messageConsumerStateList.append(messageConsumerState1)
    messageConsumerStateList.append(messageConsumerState2)
    messageConsumerStateList.append(messageConsumerState3)

    message = Message(message_id="9854215645555", start_timestamp="123504578", end_timestamp=None,
                      message_producer_state=messageProducerState, message_consumer_state_list=messageConsumerStateList,
                      message_type=MessageType.testing, message_data=messageData,
                      additional_data={"via": "yie", "fly": "fly"})

    wSJsonUtils = WSJsonUtils()
    temp_json = wSJsonUtils.transfer2json(message)
    print(temp_json)
    import json
    json_loads = json.loads(temp_json)
    print(json_loads)
    print(json_loads["message_consumer_state_list"])



import os
if __name__ == '__main__':
    print("VidoFormatTransformThread Start")
    avi_file_path = "/home/wwl/myui/myworkspace/testing/avi2mp4/aaa.avi"
    out_file_path = "/home/wwl/myui/myworkspace/testing/avi2mp4/yie.mp4"
    os.system("ffmpeg -i '{input}' -ac 2 -b:v 2000k -c:a aac -c:v libx264 -b:a 160k -vprofile high -bf 0 -strict experimental -f mp4 '{output}'".format(input=avi_file_path, output=out_file_path))
    print("VidoFormatTransformThread Finish")
    print("2")



import logging  # 引入logging模块
import os
import os.path
import time
from pathlib import Path


print("Path:"+str(Path))
# 获取当前目录
current_path = Path.cwd()
print("current_path:"+str(current_path))
home_path = Path.home()
print("home_path:"+str(home_path))
print("os.getcwd():"+str(os.getcwd()))
print("os.path.dirname(os.getcwd()):"+str(os.path.dirname(os.getcwd())))


# 第一步，创建一个logger
logger = logging.getLogger()
logger.setLevel(logging.INFO)  # Log等级总开关
# 第二步，创建一个handler，用于写入日志文件
rq = time.strftime('%Y%m%d%H%M', time.localtime(time.time()))
log_path = os.path.dirname(os.getcwd()) + '/logs/'
if not os.path.exists(log_path):
    os.makedirs(log_path)
log_name = log_path + rq + '.log'
logfile = log_name
fh = logging.FileHandler(logfile, mode='w')
fh.setLevel(logging.DEBUG)  # 输出到file的log等级的开关
# 第三步，定义handler的输出格式
formatter = logging.Formatter("%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s")
fh.setFormatter(formatter)
# 第四步，将logger添加到handler里面
logger.addHandler(fh)
# 日志
logger.debug('this is a logger debug message')
logger.info('this is a logger info message')
logger.warning('this is a logger warning message')
logger.error('this is a logger error message')
logger.critical('this is a logger critical message')


import os
import shutil


class SplitTrainingTestingValidation:

    def do_split(self, training_percentage=0.8, testing_percentage=0.1, image_and_txt_directory=None,
                 image_and_txt_result_directory=None):
        if training_percentage is None or training_percentage > 1 or training_percentage < 0 or testing_percentage is None or testing_percentage > 1 or testing_percentage < 0 or (
                testing_percentage + training_percentage) > 1:
            raise Exception("training_percentage or testing_percentage is illegal.")
        if image_and_txt_directory is None or image_and_txt_result_directory is None:
            raise Exception("image_and_txt_directory and image_and_txt_result_directory must be exist.")
        if not os.path.exists(image_and_txt_directory):
            raise Exception("image_and_txt_directory is not exist.")
        """
        training_percentage = 0.8
        testing_percentage = 0.15
        validating_percentage = 1 - training_percentage - testing_percentage
        image_and_txt_directory = r'/home/wwl/mypython/myworkspace/vialearning/mwds'
        image_and_txt_result_directory = r'/home/wwl/mypython/myworkspace/vialearning/mwdsresult1'
        """

        xml_files = os.listdir(image_and_txt_directory)
        xml_files_list = list()
        for xml_name in xml_files:
            print(xml_name)
            if str(xml_name).find(".txt") < 0:
                continue
            xml_files_list.append(xml_name)
        all_number = xml_files_list.__len__()
        training_number = int(training_percentage * all_number)
        testing_number = int(testing_percentage * all_number)
        validation_number = all_number - training_number - testing_number
        print(training_number)
        print(testing_number)
        print(validation_number)
        list1 = xml_files_list[0:training_number]
        list2 = xml_files_list[training_number:testing_number + training_number]
        list3 = xml_files_list[testing_number + training_number:]
        print(list1.__len__())
        print(list2.__len__())
        print(list3.__len__())
        dir1 = "images"
        dir2 = "labels"
        dir3 = "train"
        dir4 = "test"
        dir5 = "val"
        d1 = os.path.join(image_and_txt_result_directory, dir1, dir3)
        d2 = os.path.join(image_and_txt_result_directory, dir1, dir4)
        d3 = os.path.join(image_and_txt_result_directory, dir1, dir5)
        d4 = os.path.join(image_and_txt_result_directory, dir2, dir3)
        d5 = os.path.join(image_and_txt_result_directory, dir2, dir4)
        d6 = os.path.join(image_and_txt_result_directory, dir2, dir5)
        for d in [d1, d2, d3, d4, d5, d6]:
            if not os.path.exists(d):
                os.makedirs(d)
        for temp in list1:
            img_name = temp.replace(".txt", ".jpg")
            txt_name = temp.replace(".txt", ".txt")

            srcImage = os.path.join(image_and_txt_directory, img_name)
            srcTxt = os.path.join(image_and_txt_directory, txt_name)

            dstImage = os.path.join(d1, img_name)
            dstTxt = os.path.join(d4, txt_name)
            shutil.copy(srcImage, dstImage)
            shutil.copy(srcTxt, dstTxt)
        for temp in list2:
            img_name = temp.replace(".txt", ".jpg")
            txt_name = temp.replace(".txt", ".txt")

            srcImage = os.path.join(image_and_txt_directory, img_name)
            srcTxt = os.path.join(image_and_txt_directory, txt_name)

            dstImage = os.path.join(d2, img_name)
            dstTxt = os.path.join(d5, txt_name)
            shutil.copy(srcImage, dstImage)
            shutil.copy(srcTxt, dstTxt)
        for temp in list3:
            img_name = temp.replace(".txt", ".jpg")
            txt_name = temp.replace(".txt", ".txt")

            srcImage = os.path.join(image_and_txt_directory, img_name)
            srcTxt = os.path.join(image_and_txt_directory, txt_name)

            dstImage = os.path.join(d3, img_name)
            dstTxt = os.path.join(d6, txt_name)
            shutil.copy(srcImage, dstImage)
            shutil.copy(srcTxt, dstTxt)


if __name__ == '__main__':
    splitTrainingTestingValidation = SplitTrainingTestingValidation()
    splitTrainingTestingValidation.do_split(image_and_txt_directory='/home/wwl/mypython/myworkspace/vialearning/mwds',
                                            image_and_txt_result_directory='/home/wwl/mypython/myworkspace/vialearning/mwdsresult1')



# -*- coding: utf-8 -*- 
# @Time : 2021/7/9 下午5:39 
# @Author : Jianglin Zhang 
# @File : setup.py

from setuptools import setup, find_packages

setup(
    name="ws_common",
    version="1.0.1",
    author="Jianglin Zhang",
    author_email="jianglin.zhang@westwell-lab.com",
    description="ws common",
    # 项目主页
    url="http://www.westwell-lab.com/",
    # 你要安装的包，通过 setuptools.find_packages 找到当前目录下有哪些包
    # classifiers=[
    #     'Development Status :: 1.0.0-Alpha',
    #
    #     # 开发的目标用户
    #     'Intended Audience :: Developers',
    #
    #     # 属于什么类型
    #     'Topic :: Software Development :: Common Tools',
    #
    #     # 许可证信息
    #     'License :: OSI Approved :: GPL License',
    #
    #     # 目标 Python 版本
    #     'Programming Language :: Python :: 3.6',
    #     'Programming Language :: Python :: 3.7',
    # ],
    packages=find_packages(),

    data_files=[
        #('./', ['config/*.ini']),
        #('/home/wwl/mypython/myworkspace/test/video/', ['*.avi']),
    ],

    # 希望被打包的文件
    # package_data={
    #     '': ['*.ini'],
    #     'config': ['*.ini']
    # },
    # 不打包某些文件
    exclude_package_data={
        './logs': ['*.log']
    },
    install_requires=['opencv-python', ],
    setup_requires=['pbr'],
)



import asyncio
import time

# 一个真实的耗时操作，可以比如去爬取网页
def mysleep(x, task_name):
    time.sleep(x)
    return task_name + "____" + str(time.time())

async def mytask(task_name):
    print(task_name, 'start')
    # r = asyncio.sleep(1) # 好多教程的做法
    r = await asyncio.get_event_loop().run_in_executor(None, mysleep, 3, task_name)
    print(r)
    print(task_name, 'end')

# for x in range(0, 100):
#     loop = asyncio.get_event_loop()
#     tasks = [mytask('task1'), mytask('task2')]
#     loop.run_until_complete(asyncio.wait(tasks))
#     loop.close()
loop = asyncio.get_event_loop()
t1 = time.time()
tasks = [mytask('task1'), mytask('task2'), mytask('task3'), mytask('task4'), mytask('task5'), mytask('task6'), mytask('task7'), mytask('task8'), mytask('task9'), mytask('task10')]
loop.run_until_complete(asyncio.wait(tasks))
print(time.time()-t1)
loop.close()



# -*- coding: utf-8 -*-
# @Time : 2021/7/9 上午11:17
# @Author : Jianglin Zhang
# @File : testing.py

import xml.dom.minidom as xmldom
import os


class VocTools:
    def __init__(self, annotation_file_path):
        self.annotation_file_path = annotation_file_path
        pass

    def get_class_dict(self):
        annotation_names = [os.path.join(self.annotation_file_path, i) for i in os.listdir(self.annotation_file_path)]
        labels = dict()
        for names in annotation_names:
            xmlfilepath = names
            if str(xmlfilepath).find(".xml") < 0:
                continue
            domobj = xmldom.parse(xmlfilepath)
            # 得到元素对象
            elementobj = domobj.documentElement
            # 获得子标签
            subElementObj = elementobj.getElementsByTagName("object")
            for s in subElementObj:
                label = s.getElementsByTagName("name")[0].firstChild.data
                if None is labels.get(label):
                    labels[label] = 1
                else:
                    labels[label] = int(labels.get(label)) + 1
        d_order = sorted(labels.items(), key=lambda x: x[1], reverse=True)
        return d_order

"""
if __name__ == '__main__':
    annotation_file_path = "/home/wwl/mypython/myworkspace/vialearning/jianglinzhangdatasets/mawanpedestrianandcar"
    vocTools = VocTools(annotation_file_path)
    print(vocTools.get_class_dict())
"""